@@ -29,13 +29,16 @@ Neo4j implementation of CBM (Combined Broker Model) functionality.
 import uuid
 import json
 
-from typing import List
+from typing import List, Dict, Tuple
+
+from collections import defaultdict
 
 from ..abc_property_graph import ABCPropertyGraph, ABCPropertyGraphConstants, PropertyGraphQueryException
 from ..neo4j_property_graph import Neo4jPropertyGraph, Neo4jGraphImporter
 from .abc_cbm import ABCCBMPropertyGraph
 from .neo4j_adm import Neo4jADMGraph
 from fim.slivers.delegations import DelegationType
+from fim.slivers.attached_components import AttachedComponentsInfo, ComponentSliver, ComponentType
 
 from ...pluggable import PluggableRegistry, BrokerPluggable, PluggableType
 
@@ -100,6 +103,7 @@ class Neo4jCBMGraph(Neo4jPropertyGraph, ABCCBMPropertyGraph):
         :param adm:
         :return:
         """
+        print(f'ADM GraphID is {adm.graph_id}')
         assert adm is not None
         assert adm.graph_exists()
 
@@ -190,6 +194,21 @@ class Neo4jCBMGraph(Neo4jPropertyGraph, ABCCBMPropertyGraph):
                     # update
                     self.update_node_property(node_id=node, prop_name=self.PROP_ADM_GRAPH_IDS,
                                               prop_val=json.dumps(adm_graph_ids))
+            # also unmerge delegations
+            for del_type in [self.PROP_CAPACITY_DELEGATIONS, self.PROP_LABEL_DELEGATIONS]:
+                delegations = self.get_node_json_property_as_object(node_id=node,
+                                                                    prop_name=del_type)
+                if delegations is None:
+                    continue
+                if not isinstance(delegations, dict):
+                    raise PropertyGraphQueryException(node_id=node, graph_id=self.graph_id,
+                                                      msg=f"When unmerging graph {graph_id}, encountered wrongly"
+                                                          f"formatted {del_type} field")
+                if graph_id in delegations.keys():
+                    delegations.pop(graph_id)
+                    self.update_node_property(node_id=node, prop_name=del_type,
+                                              prop_val=json.dumps(delegations))
+
         # remove the merged nodes
         for node in delete_nodes:
             self.delete_node(node_id=node)
@@ -237,6 +256,65 @@ class Neo4jCBMGraph(Neo4jPropertyGraph, ABCCBMPropertyGraph):
         #print(f"Looking for {delegation_type} delegation from {adm_id} in {deleg_prop_val}")
         return deleg_prop_val.get(adm_id, None)
 
+    def get_matching_nodes_with_components(self, *, label: str, props: Dict,
+                                           comps: AttachedComponentsInfo = None) -> List[str]:
+        assert label is not None
+        assert props is not None
+
+        # collect unique types, models and count them
+        component_counts = defaultdict(int)
+        isset = False
+        if comps is not None:
+            for comp in comps.list_devices():
+                assert(comp.resource_model is not None or comp.resource_type is not None)
+                component_counts[(comp.resource_type, comp.resource_model)] = \
+                    component_counts[(comp.resource_type, comp.resource_model)] + 1
+                isset = True
+        # unroll properties
+        node_props = ", ".join([x + ": " + '"' + props[x] + '"' for x in props.keys()])
+
+        if not isset:
+            # simple query on the properties of the node
+            query = f"MATCH(n:{label} {{GraphID: $graphId, {node_props} }}) RETURN collect(n.NodeID) as candidate_ids"
+        else:
+            # build a query list
+            node_query = f"MATCH(n:{label} {{GraphID: $graphId, {node_props} }}) WHERE "
+            component_clauses = list()
+            # add a clause for every tuple
+            for k, v in component_counts.items():
+                comp_props_list = list()
+                if k[0] is not None:
+                    comp_props_list.append('Type: ' + '"' + str(k[0]) + '"' + ' ')
+                if k[1] is not None:
+                    comp_props_list.append('Model: ' + '"' + k[1] + '"' + ' ')
+                comp_props = ", ".join(comp_props_list)
+
+                component_clauses.append(f"size( (n) -[:has]- (:Component {{GraphID: $graphId, "
+                                         f"{comp_props}}}))>={str(v)} ")
+            query = node_query + " and ".join(component_clauses) + " RETURN collect(n.NodeID) as candidate_ids"
+        #print(f'QUERY= {query}')
+        #print(f'GraphID= {self.graph_id}')
+        with self.driver.session() as session:
+
+            val = session.run(query, graphId=self.graph_id).single()
+            #print(f'VAL= {val}')
+        if val is None:
+            return list()
+        return val.data()['candidate_ids']
+
+    def get_intersite_links(self) -> List[Tuple[str, str, str]]:
+        # does a lexicographic comparison of Site properties to ensure only unique links are returned
+        query = 'match p= (n:NetworkNode {Type:"Switch", GraphID: $graphId}) -[:has]- (:SwitchFabric) ' \
+                '-[:connects *2]- (l:Link) -[:connects *2]- (:SwitchFabric) -[:has]- ' \
+                '(m:NetworkNode {Type:"Switch", GraphID: $graphId}) where n.Site > m.Site ' \
+                'return n.NodeID as source, l.NodeID as link, m.NodeID as sink, n.Site as source_site, ' \
+                'm.Site as sink_site'
+        with self.driver.session() as session:
+            val = session.run(query, graphId=self.graph_id).values()
+        if val is None:
+            return list()
+        return val
+
 
 class Neo4jCBMFactory:
     """
