@@ -44,7 +44,7 @@ from ..graph.abc_property_graph import ABCPropertyGraph
 from ..graph.resources.networkx_adm import NetworkXADMGraph, NetworkXGraphImporter
 from ..graph.resources.abc_bqm import ABCBQMPropertyGraph
 from ..slivers.delegations import Delegation, ARMDelegations, ARMPools, DelegationType
-from fim.plugins.broker.networkx_abqm import NetworkXAggregateBQM, NetworkXABQMFactory
+from fim.graph.resources.networkx_abqm import NetworkXAggregateBQM, NetworkXABQMFactory
 
 from .model_element import ElementType
 from .node import Node
@@ -447,6 +447,7 @@ class SubstrateTopology(Topology):
                                                        delegation_id=delegation_id)
                 if delegation is not None:
                     delegations[t].add_delegation(delegation)
+                # components
                 for c in n.components.values():
                     delegation = self.__copy_to_delegation(e=c, atype=t,
                                                            delegation_id=delegation_id)
@@ -457,6 +458,18 @@ class SubstrateTopology(Topology):
                                                                delegation_id=delegation_id)
                         if delegation is not None:
                             delegations[t].add_delegation(delegation)
+                # switchfabrics (for eg switches)
+                for sf in n.switch_fabrics.values():
+                    delegation = self.__copy_to_delegation(e=sf, atype=t,
+                                                           delegation_id=delegation_id)
+                    if delegation is not None:
+                        delegations[t].add_delegation(delegation)
+                    for i in sf.interfaces.values():
+                        delegation = self.__copy_to_delegation(e=i, atype=t,
+                                                               delegation_id=delegation_id)
+                        if delegation is not None:
+                            delegations[t].add_delegation(delegation)
+
             self.as_adm().annotate_delegations_and_pools(dels=delegations[t],
                                                          pools=pool_dict[t])
 
@@ -483,7 +496,7 @@ class AdvertizedTopology(Topology):
     def add_link(self, *, name: str, node_id: str = None, ltype: LinkType = None,
                  interfaces: List[Interface], layer: SFLayer = None, technology: str = None,
                  **kwargs) -> Link:
-        raise RuntimeError('Cannod add link to advertisement')
+        raise RuntimeError('Cannot add link to advertisement')
 
     def load(self, *, file_name: str = None, graph_string: str = None):
         """
